.. _cli:

Tax-Brain Command Line Interface
======================================

**cli**

taxbrain.cli
------------------------------------------

.. currentmodule:: taxbrain.cli

.. automodule:: taxbrain.cli
  :members: make_tables, cli_core, cli_main
